Welcome to Django Kamasutra’s documentation! — Django Kamasutra v0.2.2 documentation

Django Kamasutra v0.2.2 documentation

# Welcome to Django Kamasutra’s documentation!

- Table of Contents
- index
  next

# Welcome to Django Kamasutra’s documentation!

Django Kamasutra is a way to feature types of content.

Contents:

- Installation
- Getting Started
  - Creating your first position
  - Add something to your Position
  - Retrieve your position content
  - Retrieve your position content via templatetag
- API
  - Position
  - PositionContent
- Reference
  - Template Tags
  - Settings
  - Rendering Content

# Helping Out

- Project Home Page https://github.com/washingtontimes/django-kamasutra/

# Indices and tables

- Index
- Module Index
- Search Page